@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
+from __future__ import absolute_import, division, print_function
 
+import sys
 import operator
 import _pytest
 import py
@@ -25,7 +27,7 @@ else:
 import pytest
 pytest_version_info = tuple(map(int, pytest.__version__.split(".")[:3]))
 
-class TWMock:
+class TWMock(object):
     WRITE = object()
 
     def __init__(self):
@@ -89,7 +91,7 @@ def h():
     g()
     #
 
-class TestTraceback_f_g_h:
+class TestTraceback_f_g_h(object):
     def setup_method(self, method):
         try:
             h()
@@ -369,7 +371,7 @@ def test_codepath_Queue_example():
 
 def test_match_succeeds():
     with pytest.raises(ZeroDivisionError) as excinfo:
-        0 / 0
+        0 // 0
     excinfo.match(r'.*zero.*')
 
 def test_match_raises_error(testdir):
@@ -386,7 +388,7 @@ def test_match_raises_error(testdir):
         "*AssertionError*Pattern*[123]*not found*",
     ])
 
-class TestFormattedExcinfo:
+class TestFormattedExcinfo(object):
 
     @pytest.fixture
     def importasmod(self, request):
@@ -472,7 +474,7 @@ raise ValueError()
         pr = FormattedExcinfo()
 
         class FakeCode(object):
-            class raw:
+            class raw(object):
                 co_filename = '?'
 
             path = '?'
@@ -1139,3 +1141,58 @@ def test_cwd_deleted(testdir):
     result = testdir.runpytest()
     result.stdout.fnmatch_lines(['* 1 failed in *'])
     assert 'INTERNALERROR' not in result.stdout.str() + result.stderr.str()
+
+
+def test_exception_repr_extraction_error_on_recursion():
+    """
+    Ensure we can properly detect a recursion error even
+    if some locals raise error on comparision (#2459).
+    """
+    class numpy_like(object):
+
+        def __eq__(self, other):
+            if type(other) is numpy_like:
+                raise ValueError('The truth value of an array '
+                                 'with more than one element is ambiguous.')
+
+    def a(x):
+        return b(numpy_like())
+
+    def b(x):
+        return a(numpy_like())
+
+    try:
+        a(numpy_like())
+    except:
+        from _pytest._code.code import ExceptionInfo
+        from _pytest.pytester import LineMatcher
+        exc_info = ExceptionInfo()
+
+        matcher = LineMatcher(str(exc_info.getrepr()).splitlines())
+        matcher.fnmatch_lines([
+            '!!! Recursion error detected, but an error occurred locating the origin of recursion.',
+            '*The following exception happened*',
+            '*ValueError: The truth value of an array*',
+        ])
+
+
+def test_no_recursion_index_on_recursion_error():
+    """
+    Ensure that we don't break in case we can't find the recursion index
+    during a recursion error (#2486).
+    """
+    try:
+        class RecursionDepthError(object):
+            def __getattr__(self, attr):
+                return getattr(self, '_' + attr)
+
+        RecursionDepthError().trigger
+    except:
+        from _pytest._code.code import ExceptionInfo
+        exc_info = ExceptionInfo()
+        if sys.version_info[:2] == (2, 6):
+            assert "'RecursionDepthError' object has no attribute '___" in str(exc_info.getrepr())
+        else:
+            assert 'maximum recursion' in str(exc_info.getrepr())
+    else:
+        assert 0
