@@ -20,7 +20,7 @@ def test_getfuncargnames():
     def h(arg1, arg2, arg3="hello"): pass
     assert fixtures.getfuncargnames(h) == ('arg1', 'arg2')
 
-    class A:
+    class A(object):
         def f(self, arg1, arg2="hello"):
             pass
 
@@ -28,7 +28,7 @@ def test_getfuncargnames():
     if sys.version_info < (3,0):
         assert fixtures.getfuncargnames(A.f) == ('arg1',)
 
-class TestFillFixtures:
+class TestFillFixtures(object):
     def test_fillfuncargs_exposed(self):
         # used by oejskit, kept for compatibility
         assert pytest._fillfuncargs == fixtures.fillfixtures
@@ -79,7 +79,7 @@ class TestFillFixtures:
             def something(request):
                 return request.function.__name__
 
-            class TestClass:
+            class TestClass(object):
                 def test_method(self, something):
                     assert something == "test_method"
             def test_func(something):
@@ -91,7 +91,7 @@ class TestFillFixtures:
     def test_funcarg_lookup_classlevel(self, testdir):
         p = testdir.makepyfile("""
             import pytest
-            class TestClass:
+            class TestClass(object):
 
                 @pytest.fixture
                 def something(self, request):
@@ -134,7 +134,7 @@ class TestFillFixtures:
             def spam():
                 return 'spam'
 
-            class TestSpam:
+            class TestSpam(object):
 
                  @pytest.fixture
                  def spam(self, spam):
@@ -463,7 +463,7 @@ class TestFillFixtures:
         assert result.ret == 0
 
 
-class TestRequestBasic:
+class TestRequestBasic(object):
     def test_request_attributes(self, testdir):
         item = testdir.getitem("""
             import pytest
@@ -484,7 +484,7 @@ class TestRequestBasic:
     def test_request_attributes_method(self, testdir):
         item, = testdir.getitems("""
             import pytest
-            class TestB:
+            class TestB(object):
 
                 @pytest.fixture
                 def something(self, request):
@@ -502,7 +502,7 @@ class TestRequestBasic:
             @pytest.fixture
             def something(request):
                 pass
-            class TestClass:
+            class TestClass(object):
                 def test_method(self, something):
                     pass
         """)
@@ -545,22 +545,33 @@ class TestRequestBasic:
                 return l.pop()
             def test_func(something): pass
         """)
+        import contextlib
+        if getfixmethod == 'getfuncargvalue':
+            warning_expectation = pytest.warns(DeprecationWarning)
+        else:
+            # see #1830 for a cleaner way to accomplish this
+            @contextlib.contextmanager
+            def expecting_no_warning(): yield
+
+            warning_expectation = expecting_no_warning()
+
         req = item._request
-        fixture_fetcher = getattr(req, getfixmethod)
-        pytest.raises(FixtureLookupError, fixture_fetcher, "notexists")
-        val = fixture_fetcher("something")
-        assert val == 1
-        val = fixture_fetcher("something")
-        assert val == 1
-        val2 = fixture_fetcher("other")
-        assert val2 == 2
-        val2 = fixture_fetcher("other")  # see about caching
-        assert val2 == 2
-        pytest._fillfuncargs(item)
-        assert item.funcargs["something"] == 1
-        assert len(get_public_names(item.funcargs)) == 2
-        assert "request" in item.funcargs
-        #assert item.funcargs == {'something': 1, "other": 2}
+        with warning_expectation:
+            fixture_fetcher = getattr(req, getfixmethod)
+            with pytest.raises(FixtureLookupError):
+                fixture_fetcher("notexists")
+            val = fixture_fetcher("something")
+            assert val == 1
+            val = fixture_fetcher("something")
+            assert val == 1
+            val2 = fixture_fetcher("other")
+            assert val2 == 2
+            val2 = fixture_fetcher("other")  # see about caching
+            assert val2 == 2
+            pytest._fillfuncargs(item)
+            assert item.funcargs["something"] == 1
+            assert len(get_public_names(item.funcargs)) == 2
+            assert "request" in item.funcargs
 
     def test_request_addfinalizer(self, testdir):
         item = testdir.getitem("""
@@ -646,6 +657,39 @@ class TestRequestBasic:
             "*1 error*"  # XXX the whole module collection fails
             ])
 
+    def test_request_subrequest_addfinalizer_exceptions(self, testdir):
+        """
+        Ensure exceptions raised during teardown by a finalizer are suppressed
+        until all finalizers are called, re-raising the first exception (#2440)
+        """
+        testdir.makepyfile("""
+            import pytest
+            l = []
+            def _excepts(where):
+                raise Exception('Error in %s fixture' % where)
+            @pytest.fixture
+            def subrequest(request):
+                return request
+            @pytest.fixture
+            def something(subrequest):
+                subrequest.addfinalizer(lambda: l.append(1))
+                subrequest.addfinalizer(lambda: l.append(2))
+                subrequest.addfinalizer(lambda: _excepts('something'))
+            @pytest.fixture
+            def excepts(subrequest):
+                subrequest.addfinalizer(lambda: _excepts('excepts'))
+                subrequest.addfinalizer(lambda: l.append(3))
+            def test_first(something, excepts):
+                pass
+            def test_second():
+                assert l == [3, 2, 1]
+        """)
+        result = testdir.runpytest()
+        result.stdout.fnmatch_lines([
+            '*Exception: Error in excepts fixture',
+            '* 2 passed, 1 error in *',
+        ])
+
     def test_request_getmodulepath(self, testdir):
         modcol = testdir.getmodulecol("def test_somefunc(): pass")
         item, = testdir.genitems([modcol])
@@ -704,7 +748,7 @@ class TestRequestBasic:
             def test_func():
                 pass
 
-            class TestClass:
+            class TestClass(object):
                 @pytest.fixture(scope="class", autouse=True)
                 def setup_class(self):
                     l.append("class")
@@ -771,7 +815,7 @@ class TestRequestBasic:
         reprec = testdir.inline_run()
         reprec.assertoutcome(passed=2)
 
-class TestRequestMarking:
+class TestRequestMarking(object):
     def test_applymarker(self, testdir):
         item1,item2 = testdir.getitems("""
             import pytest
@@ -779,7 +823,7 @@ class TestRequestMarking:
             @pytest.fixture
             def something(request):
                 pass
-            class TestClass:
+            class TestClass(object):
                 def test_func1(self, something):
                     pass
                 def test_func2(self, something):
@@ -831,7 +875,7 @@ class TestRequestMarking:
         reprec = testdir.inline_run()
         reprec.assertoutcome(passed=2)
 
-class TestRequestCachedSetup:
+class TestRequestCachedSetup(object):
     def test_request_cachedsetup_defaultmodule(self, testdir):
         reprec = testdir.inline_runsource("""
             mysetup = ["hello",].pop
@@ -844,7 +888,7 @@ class TestRequestCachedSetup:
 
             def test_func1(something):
                 assert something == "hello"
-            class TestClass:
+            class TestClass(object):
                 def test_func1a(self, something):
                     assert something == "hello"
         """)
@@ -862,7 +906,7 @@ class TestRequestCachedSetup:
                 assert something == "hello3"
             def test_func2(something):
                 assert something == "hello2"
-            class TestClass:
+            class TestClass(object):
                 def test_func1a(self, something):
                     assert something == "hello"
                 def test_func2b(self, something):
@@ -996,7 +1040,7 @@ class TestRequestCachedSetup:
             "*ZeroDivisionError*",
         ])
 
-class TestFixtureUsages:
+class TestFixtureUsages(object):
     def test_noargfixturedec(self, testdir):
         testdir.makepyfile("""
             import pytest
@@ -1138,7 +1182,7 @@ class TestFixtureUsages:
     def test_factory_setup_as_classes_fails(self, testdir):
         testdir.makepyfile("""
             import pytest
-            class arg1:
+            class arg1(object):
                 def __init__(self, request):
                     self.x = 1
             arg1 = pytest.fixture()(arg1)
@@ -1172,7 +1216,7 @@ class TestFixtureUsages:
                 request.cls.hello = "world"
                 l.append(1)
 
-            class TestClass:
+            class TestClass(object):
                 def test_one(self):
                     assert self.hello == "world"
                     assert len(l) == 1
@@ -1198,7 +1242,7 @@ class TestFixtureUsages:
 
         """)
         testdir.makepyfile("""
-            class TestClass:
+            class TestClass(object):
                 def test_one(self):
                     assert self.hello == "world"
                 def test_two(self):
@@ -1217,7 +1261,7 @@ class TestFixtureUsages:
         testdir.makepyfile("""
             import pytest
 
-            class TestClass:
+            class TestClass(object):
                 @pytest.fixture
                 def setup1(self, request):
                     assert self == request.instance
@@ -1256,7 +1300,7 @@ class TestFixtureUsages:
         assert l == [1,2, 10,20]
 
 
-class TestFixtureManagerParseFactories:
+class TestFixtureManagerParseFactories(object):
 
     @pytest.fixture
     def testdir(self, request):
@@ -1280,7 +1324,7 @@ class TestFixtureManagerParseFactories:
 
     def test_parsefactories_evil_objects_issue214(self, testdir):
         testdir.makepyfile("""
-            class A:
+            class A(object):
                 def __call__(self):
                     pass
                 def __getattr__(self, name):
@@ -1311,7 +1355,7 @@ class TestFixtureManagerParseFactories:
             @pytest.fixture
             def hello(request):
                 return "module"
-            class TestClass:
+            class TestClass(object):
                 @pytest.fixture
                 def hello(self, request):
                     return "class"
@@ -1360,7 +1404,7 @@ class TestFixtureManagerParseFactories:
             reprec.assertoutcome(passed=2)
 
 
-class TestAutouseDiscovery:
+class TestAutouseDiscovery(object):
 
     @pytest.fixture
     def testdir(self, testdir):
@@ -1402,14 +1446,14 @@ class TestAutouseDiscovery:
     def test_two_classes_separated_autouse(self, testdir):
         testdir.makepyfile("""
             import pytest
-            class TestA:
+            class TestA(object):
                 l = []
                 @pytest.fixture(autouse=True)
                 def setup1(self):
                     self.l.append(1)
                 def test_setup1(self):
                     assert self.l == [1]
-            class TestB:
+            class TestB(object):
                 l = []
                 @pytest.fixture(autouse=True)
                 def setup2(self):
@@ -1423,7 +1467,7 @@ class TestAutouseDiscovery:
     def test_setup_at_classlevel(self, testdir):
         testdir.makepyfile("""
             import pytest
-            class TestClass:
+            class TestClass(object):
                 @pytest.fixture(autouse=True)
                 def permethod(self, request):
                     request.instance.funcname = request.function.__name__
@@ -1505,13 +1549,13 @@ class TestAutouseDiscovery:
             def test_x():
                 assert l == ["module"]
 
-            class TestA:
+            class TestA(object):
                 @pytest.fixture(autouse=True)
                 def append2(self):
                     l.append("A")
                 def test_hello(self):
                     assert l == ["module", "module", "A"], l
-            class TestA2:
+            class TestA2(object):
                 def test_world(self):
                     assert l == ["module", "module", "A", "module"], l
         """)
@@ -1519,7 +1563,7 @@ class TestAutouseDiscovery:
         reprec.assertoutcome(passed=3)
 
 
-class TestAutouseManagement:
+class TestAutouseManagement(object):
     def test_autouse_conftest_mid_directory(self, testdir):
         pkgdir = testdir.mkpydir("xyz123")
         pkgdir.join("conftest.py").write(_pytest._code.Source("""
@@ -1654,10 +1698,10 @@ class TestAutouseManagement:
         testdir.makepyfile("""
             import pytest
 
-            class TestClass:
+            class TestClass(object):
                 def test_1(self):
                     pass
-            class TestClass2:
+            class TestClass2(object):
                 def test_2(self):
                     pass
         """)
@@ -1682,7 +1726,7 @@ class TestAutouseManagement:
             def mappend():
                 l.append(1)
 
-            class TestHallo:
+            class TestHallo(object):
                 def test_method(self):
                     assert l == [1,3,2]
         """)
@@ -1696,7 +1740,7 @@ class TestAutouseManagement:
             def pytest_generate_tests(metafunc):
                 if metafunc.cls is not None:
                     metafunc.parametrize("item", [1,2], scope="class")
-            class TestClass:
+            class TestClass(object):
                 @pytest.fixture(scope="class", autouse=True)
                 def addteardown(self, item, request):
                     l.append("setup-%d" % item)
@@ -1756,7 +1800,7 @@ class TestAutouseManagement:
         reprec.assertoutcome(passed=2)
 
 
-class TestFixtureMarker:
+class TestFixtureMarker(object):
     def test_parametrize(self, testdir):
         testdir.makepyfile("""
             import pytest
@@ -1822,7 +1866,7 @@ class TestFixtureMarker:
             def test_2(arg):
                 assert arg == 1
                 assert len(l) == 1
-            class TestClass:
+            class TestClass(object):
                 def test3(self, arg):
                     assert arg == 1
                     assert len(l) == 1
@@ -1916,7 +1960,7 @@ class TestFixtureMarker:
             def test_2(arg):
                 assert arg == 1
                 assert len(l) == 1
-            class TestClass:
+            class TestClass(object):
                 def test3(self, arg):
                     assert arg == 1
                     assert len(l) == 1
@@ -2135,12 +2179,12 @@ class TestFixtureMarker:
         testdir.makepyfile("""
             import pytest
 
-            class TestClass2:
+            class TestClass2(object):
                 def test_1(self):
                     pass
                 def test_2(self):
                     pass
-            class TestClass:
+            class TestClass(object):
                 def test_3(self):
                     pass
         """)
@@ -2213,7 +2257,7 @@ class TestFixtureMarker:
 
             l = []
 
-            class TestClass:
+            class TestClass(object):
                 @classmethod
                 @pytest.fixture(scope="class", autouse=True)
                 def setup1(self, request, param1):
@@ -2273,7 +2317,7 @@ class TestFixtureMarker:
         testpath = testdir.makepyfile("""
             import pytest
 
-            class Box:
+            class Box(object):
                 value = 0
 
             @pytest.fixture(scope='class')
@@ -2284,11 +2328,11 @@ class TestFixtureMarker:
             def test_a(a):
                 assert a == 1
 
-            class Test1:
+            class Test1(object):
                 def test_b(self, a):
                     assert a == 2
 
-            class Test2:
+            class Test2(object):
                 def test_c(self, a):
                     assert a == 3""")
         reprec = testdir.inline_run(testpath)
@@ -2402,11 +2446,11 @@ class TestFixtureMarker:
                 request.addfinalizer(lambda: l.append("fin %s" % request.param))
                 return request.param
 
-            class TestGreetings:
+            class TestGreetings(object):
                 def test_hello(self, human):
                     l.append("test_hello")
 
-            class TestMetrics:
+            class TestMetrics(object):
                 def test_name(self, human):
                     l.append("test_name")
 
@@ -2499,7 +2543,7 @@ class TestFixtureMarker:
             '*test_foo*beta*'])
 
 
-class TestRequestScopeAccess:
+class TestRequestScopeAccess(object):
     pytestmark = pytest.mark.parametrize(("scope", "ok", "error"),[
         ["session", "", "fspath class function module"],
         ["module", "module fspath", "cls function"],
@@ -2543,7 +2587,7 @@ class TestRequestScopeAccess:
         reprec = testdir.inline_run()
         reprec.assertoutcome(passed=1)
 
-class TestErrors:
+class TestErrors(object):
     def test_subfactory_missing_funcarg(self, testdir):
         testdir.makepyfile("""
             import pytest
@@ -2607,7 +2651,7 @@ class TestErrors:
             "*1 error*",
         ])
 
-class TestShowFixtures:
+class TestShowFixtures(object):
     def test_funcarg_compat(self, testdir):
         config = testdir.parseconfigure("--funcargs")
         assert config.option.showfixtures
@@ -2770,7 +2814,7 @@ class TestShowFixtures:
 
 
 @pytest.mark.parametrize('flavor', ['fixture', 'yield_fixture'])
-class TestContextManagerFixtureFuncs:
+class TestContextManagerFixtureFuncs(object):
 
     def test_simple(self, testdir, flavor):
         testdir.makepyfile("""
@@ -2877,7 +2921,7 @@ class TestContextManagerFixtureFuncs:
         result = testdir.runpytest("-s")
         result.stdout.fnmatch_lines("*mew*")
 
-class TestParameterizedSubRequest:
+class TestParameterizedSubRequest(object):
     def test_call_from_fixture(self, testdir):
         testfile = testdir.makepyfile("""
             import pytest
