@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from __future__ import absolute_import, division, print_function
 import sys
 import textwrap
 
@@ -6,6 +7,7 @@ import _pytest.assertion as plugin
 import py
 import pytest
 from _pytest.assertion import util
+from _pytest.assertion import truncate
 
 PY3 = sys.version_info >= (3, 0)
 
@@ -24,7 +26,7 @@ def mock_config():
     return Config()
 
 
-class TestImportHookInstallation:
+class TestImportHookInstallation(object):
 
     @pytest.mark.parametrize('initial_conftest', [True, False])
     @pytest.mark.parametrize('mode', ['plain', 'rewrite'])
@@ -158,7 +160,7 @@ class TestImportHookInstallation:
 
             plugin_state = "{plugin_state}"
 
-            class DummyDistInfo:
+            class DummyDistInfo(object):
                 project_name = 'spam'
                 version = '1.0'
 
@@ -173,7 +175,7 @@ class TestImportHookInstallation:
                                 'hampkg/__init__.py']
                     return []
 
-            class DummyEntryPoint:
+            class DummyEntryPoint(object):
                 name = 'spam'
                 module_name = 'spam.py'
                 attrs = ()
@@ -256,7 +258,7 @@ class TestImportHookInstallation:
                                        'pytest_tests_internal_non_existing2')
 
 
-class TestBinReprIntegration:
+class TestBinReprIntegration(object):
 
     def test_pytest_assertrepr_compare_called(self, testdir):
         testdir.makeconftest("""
@@ -287,7 +289,7 @@ def callequal(left, right, verbose=False):
     return plugin.pytest_assertrepr_compare(config, '==', left, right)
 
 
-class TestAssert_reprcompare:
+class TestAssert_reprcompare(object):
     def test_different_types(self):
         assert callequal([0, 1], 'foo') is None
 
@@ -364,7 +366,7 @@ class TestAssert_reprcompare:
         expl = '\n'.join(callequal(left, right, verbose=True))
         assert expl.endswith(textwrap.dedent(expected).strip())
 
-    def test_list_different_lenghts(self):
+    def test_list_different_lengths(self):
         expl = callequal([0, 1], [0, 1, 2])
         assert len(expl) > 1
         expl = callequal([0, 1, 2], [0, 1])
@@ -381,8 +383,16 @@ class TestAssert_reprcompare:
         for line in lines[1:]:
             assert 'b' not in line
 
-    def test_dict_omitting_verbose(self):
-        lines = callequal({'a': 0, 'b': 1}, {'a': 1, 'b': 1}, verbose=True)
+    def test_dict_omitting_with_verbosity_1(self):
+        """ Ensure differing items are visible for verbosity=1 (#1512) """
+        lines = callequal({'a': 0, 'b': 1}, {'a': 1, 'b': 1}, verbose=1)
+        assert lines[1].startswith('Omitting 1 identical item')
+        assert lines[2].startswith('Differing items')
+        assert lines[3] == "{'a': 0} != {'a': 1}"
+        assert 'Common items' not in lines
+
+    def test_dict_omitting_with_verbosity_2(self):
+        lines = callequal({'a': 0, 'b': 1}, {'a': 1, 'b': 1}, verbose=2)
         assert lines[1].startswith('Common items:')
         assert 'Omitting' not in lines[1]
         assert lines[2] == "{'b': 1}"
@@ -433,7 +443,7 @@ class TestAssert_reprcompare:
         assert len(expl) > 1
 
     def test_list_bad_repr(self):
-        class A:
+        class A(object):
             def __repr__(self):
                 raise ValueError(42)
         expl = callequal([], [A()])
@@ -492,7 +502,7 @@ class TestAssert_reprcompare:
         assert msg
 
 
-class TestFormatExplanation:
+class TestFormatExplanation(object):
 
     def test_special_chars_full(self, testdir):
         # Issue 453, for the bug this would raise IndexError
@@ -584,6 +594,111 @@ class TestFormatExplanation:
         assert util.format_explanation(expl) == res
 
 
+class TestTruncateExplanation(object):
+
+    """ Confirm assertion output is truncated as expected """
+
+    # The number of lines in the truncation explanation message. Used
+    # to calculate that results have the expected length.
+    LINES_IN_TRUNCATION_MSG = 2
+
+    def test_doesnt_truncate_when_input_is_empty_list(self):
+        expl = []
+        result = truncate._truncate_explanation(expl, max_lines=8, max_chars=100)
+        assert result == expl
+
+    def test_doesnt_truncate_at_when_input_is_5_lines_and_LT_max_chars(self):
+        expl = ['a' * 100 for x in range(5)]
+        result = truncate._truncate_explanation(expl, max_lines=8, max_chars=8*80)
+        assert result == expl
+
+    def test_truncates_at_8_lines_when_given_list_of_empty_strings(self):
+        expl = ['' for x in range(50)]
+        result = truncate._truncate_explanation(expl, max_lines=8, max_chars=100)
+        assert result != expl
+        assert len(result) == 8 + self.LINES_IN_TRUNCATION_MSG
+        assert "Full output truncated" in result[-1]
+        assert "43 lines hidden" in result[-1]
+        last_line_before_trunc_msg = result[- self.LINES_IN_TRUNCATION_MSG -1]
+        assert last_line_before_trunc_msg.endswith("...")
+
+    def test_truncates_at_8_lines_when_first_8_lines_are_LT_max_chars(self):
+        expl = ['a' for x in range(100)]
+        result = truncate._truncate_explanation(expl, max_lines=8, max_chars=8*80)
+        assert result != expl
+        assert len(result) == 8 + self.LINES_IN_TRUNCATION_MSG
+        assert "Full output truncated" in result[-1]
+        assert "93 lines hidden" in result[-1]
+        last_line_before_trunc_msg = result[- self.LINES_IN_TRUNCATION_MSG -1]
+        assert last_line_before_trunc_msg.endswith("...")
+
+    def test_truncates_at_8_lines_when_first_8_lines_are_EQ_max_chars(self):
+        expl = ['a' * 80 for x in range(16)]
+        result = truncate._truncate_explanation(expl, max_lines=8, max_chars=8*80)
+        assert result != expl
+        assert len(result) == 8 + self.LINES_IN_TRUNCATION_MSG
+        assert "Full output truncated" in result[-1]
+        assert "9 lines hidden" in result[-1]
+        last_line_before_trunc_msg = result[- self.LINES_IN_TRUNCATION_MSG -1]
+        assert last_line_before_trunc_msg.endswith("...")
+
+    def test_truncates_at_4_lines_when_first_4_lines_are_GT_max_chars(self):
+        expl = ['a' * 250 for x in range(10)]
+        result = truncate._truncate_explanation(expl, max_lines=8, max_chars=999)
+        assert result != expl
+        assert len(result) == 4 + self.LINES_IN_TRUNCATION_MSG
+        assert "Full output truncated" in result[-1]
+        assert "7 lines hidden" in result[-1]
+        last_line_before_trunc_msg = result[- self.LINES_IN_TRUNCATION_MSG -1]
+        assert last_line_before_trunc_msg.endswith("...")
+
+    def test_truncates_at_1_line_when_first_line_is_GT_max_chars(self):
+        expl = ['a' * 250 for x in range(1000)]
+        result = truncate._truncate_explanation(expl, max_lines=8, max_chars=100)
+        assert result != expl
+        assert len(result) == 1 + self.LINES_IN_TRUNCATION_MSG
+        assert "Full output truncated" in result[-1]
+        assert "1000 lines hidden" in result[-1]
+        last_line_before_trunc_msg = result[- self.LINES_IN_TRUNCATION_MSG -1]
+        assert last_line_before_trunc_msg.endswith("...")
+
+    def test_full_output_truncated(self, monkeypatch, testdir):
+        """ Test against full runpytest() output. """
+
+        line_count = 7
+        line_len = 100
+        expected_truncated_lines = 2
+        testdir.makepyfile(r"""
+            def test_many_lines():
+                a = list([str(i)[0] * %d for i in range(%d)])
+                b = a[::2]
+                a = '\n'.join(map(str, a))
+                b = '\n'.join(map(str, b))
+                assert a == b
+        """ % (line_len, line_count))
+        monkeypatch.delenv('CI', raising=False)
+
+        result = testdir.runpytest()
+        # without -vv, truncate the message showing a few diff lines only
+        result.stdout.fnmatch_lines([
+            "*- 1*",
+            "*- 3*",
+            "*- 5*",
+            "*truncated (%d lines hidden)*use*-vv*" % expected_truncated_lines,
+        ])
+
+        result = testdir.runpytest('-vv')
+        result.stdout.fnmatch_lines([
+            "* 6*",
+        ])
+
+        monkeypatch.setenv('CI', '1')
+        result = testdir.runpytest()
+        result.stdout.fnmatch_lines([
+            "* 6*",
+        ])
+
+
 def test_python25_compile_issue257(testdir):
     testdir.makepyfile("""
         def test_rewritten():
@@ -643,40 +758,6 @@ def test_sequence_comparison_uses_repr(testdir):
     ])
 
 
-def test_assert_compare_truncate_longmessage(monkeypatch, testdir):
-    testdir.makepyfile(r"""
-        def test_long():
-            a = list(range(200))
-            b = a[::2]
-            a = '\n'.join(map(str, a))
-            b = '\n'.join(map(str, b))
-            assert a == b
-    """)
-    monkeypatch.delenv('CI', raising=False)
-
-    result = testdir.runpytest()
-    # without -vv, truncate the message showing a few diff lines only
-    result.stdout.fnmatch_lines([
-        "*- 1",
-        "*- 3",
-        "*- 5",
-        "*- 7",
-        "*truncated (193 more lines)*use*-vv*",
-    ])
-
-
-    result = testdir.runpytest('-vv')
-    result.stdout.fnmatch_lines([
-        "*- 197",
-    ])
-
-    monkeypatch.setenv('CI', '1')
-    result = testdir.runpytest()
-    result.stdout.fnmatch_lines([
-        "*- 197",
-    ])
-
-
 def test_assertrepr_loaded_per_dir(testdir):
     testdir.makepyfile(test_base=['def test_base(): assert 1 == 2'])
     a = testdir.mkdir('a')
@@ -895,7 +976,10 @@ def test_assert_tuple_warning(testdir):
             assert(False, 'you shall not pass')
     """)
     result = testdir.runpytest('-rw')
-    result.stdout.fnmatch_lines('WR1*:2 assertion is always true*')
+    result.stdout.fnmatch_lines([
+        '*test_assert_tuple_warning.py:2',
+        '*assertion is always true*',
+    ])
 
 def test_assert_indirect_tuple_no_warning(testdir):
     testdir.makepyfile("""
@@ -916,6 +1000,25 @@ def test_assert_with_unicode(monkeypatch, testdir):
     result = testdir.runpytest()
     result.stdout.fnmatch_lines(['*AssertionError*'])
 
+def test_raise_unprintable_assertion_error(testdir):
+    testdir.makepyfile(r"""
+        def test_raise_assertion_error():
+            raise AssertionError('\xff')
+    """)
+    result = testdir.runpytest()
+    result.stdout.fnmatch_lines([r">       raise AssertionError('\xff')", 'E       AssertionError: *'])
+
+def test_raise_assertion_error_raisin_repr(testdir):
+    testdir.makepyfile(u"""
+        class RaisingRepr(object):
+            def __repr__(self):
+                raise Exception()
+        def test_raising_repr():
+            raise AssertionError(RaisingRepr())
+    """)
+    result = testdir.runpytest()
+    result.stdout.fnmatch_lines(['E       AssertionError: <unprintable AssertionError object>'])
+
 def test_issue_1944(testdir):
     testdir.makepyfile("""
         def f():
@@ -926,4 +1029,3 @@ def test_issue_1944(testdir):
     result = testdir.runpytest()
     result.stdout.fnmatch_lines(["*1 error*"])
     assert "AttributeError: 'Module' object has no attribute '_obj'" not in result.stdout.str()
-
