@@ -1,3 +1,4 @@
+from __future__ import absolute_import, division, print_function
 import sys
 
 import _pytest
@@ -7,7 +8,7 @@ import shutil
 
 pytest_plugins = "pytester",
 
-class TestNewAPI:
+class TestNewAPI(object):
     def test_config_cache_makedir(self, testdir):
         testdir.makeini("[pytest]")
         config = testdir.parseconfigure()
@@ -46,15 +47,15 @@ class TestNewAPI:
     def test_cache_failure_warns(self, testdir):
         testdir.tmpdir.ensure_dir('.cache').chmod(0)
         testdir.makepyfile("""
-            def test_pass():
-                pass
+            def test_error():
+                raise Exception
 
         """)
         result = testdir.runpytest('-rw')
-        assert result.ret == 0
+        assert result.ret == 1
         result.stdout.fnmatch_lines([
             "*could not create cache path*",
-            "*1 pytest-warnings*",
+            "*1 warnings*",
         ])
 
     def test_config_cache(self, testdir):
@@ -129,7 +130,7 @@ def test_cache_show(testdir):
     ])
 
 
-class TestLastFailed:
+class TestLastFailed(object):
 
     def test_lastfailed_usecase(self, testdir, monkeypatch):
         monkeypatch.setenv("PYTHONDONTWRITEBYTECODE", 1)
@@ -191,13 +192,37 @@ class TestLastFailed:
             "test_a.py*",
             "test_b.py*",
         ])
-        result = testdir.runpytest("--lf", "--ff")
+        result = testdir.runpytest("--ff")
         # Test order will be failing tests firs
         result.stdout.fnmatch_lines([
             "test_b.py*",
             "test_a.py*",
         ])
 
+    def test_lastfailed_failedfirst_order(self, testdir):
+        testdir.makepyfile(**{
+            'test_a.py': """
+                def test_always_passes():
+                    assert 1
+            """,
+            'test_b.py': """
+                def test_always_fails():
+                    assert 0
+            """,
+        })
+        result = testdir.runpytest()
+        # Test order will be collection order; alphabetical
+        result.stdout.fnmatch_lines([
+            "test_a.py*",
+            "test_b.py*",
+        ])
+        result = testdir.runpytest("--lf", "--ff")
+        # Test order will be failing tests firs
+        result.stdout.fnmatch_lines([
+            "test_b.py*",
+        ])
+        assert 'test_a.py' not in result.stdout.str()
+
     def test_lastfailed_difference_invocations(self, testdir, monkeypatch):
         monkeypatch.setenv("PYTHONDONTWRITEBYTECODE", 1)
         testdir.makepyfile(test_a="""
@@ -266,7 +291,7 @@ class TestLastFailed:
         """)
         config = testdir.parseconfigure()
         lastfailed = config.cache.get("cache/lastfailed", -1)
-        assert not lastfailed
+        assert lastfailed == -1
 
     def test_non_serializable_parametrize(self, testdir):
         """Test that failed parametrized tests with unmarshable parameters
@@ -305,7 +330,7 @@ class TestLastFailed:
             return lastfailed
 
         lastfailed = rlf(fail_import=0, fail_run=0)
-        assert not lastfailed
+        assert lastfailed == -1
 
         lastfailed = rlf(fail_import=1, fail_run=0)
         assert list(lastfailed) == ['test_maybe.py']
@@ -347,7 +372,7 @@ class TestLastFailed:
             return result, lastfailed
 
         result, lastfailed = rlf(fail_import=0, fail_run=0)
-        assert not lastfailed
+        assert lastfailed == -1
         result.stdout.fnmatch_lines([
             '*3 passed*',
         ])
@@ -370,3 +395,17 @@ class TestLastFailed:
         result.stdout.fnmatch_lines([
             '*2 passed*',
         ])
+
+    def test_lastfailed_creates_cache_when_needed(self, testdir):
+        # Issue #1342
+        testdir.makepyfile(test_empty='')
+        testdir.runpytest('-q', '--lf')
+        assert not os.path.exists('.cache')
+
+        testdir.makepyfile(test_successful='def test_success():\n    assert True')
+        testdir.runpytest('-q', '--lf')
+        assert not os.path.exists('.cache')
+
+        testdir.makepyfile(test_errored='def test_error():\n    assert False')
+        testdir.runpytest('-q', '--lf')
+        assert os.path.exists('.cache')
