@@ -1,8 +1,9 @@
+from __future__ import absolute_import, division, print_function
 import pytest, py
 
 from _pytest.main import Session, EXIT_NOTESTSCOLLECTED
 
-class TestCollector:
+class TestCollector(object):
     def test_collect_versus_item(self):
         from pytest import Collector, Item
         assert not issubclass(Collector, Item)
@@ -50,7 +51,7 @@ class TestCollector:
 
     def test_getparent(self, testdir):
         modcol = testdir.getmodulecol("""
-            class TestClass:
+            class TestClass(object):
                  def test_foo():
                      pass
         """)
@@ -85,7 +86,23 @@ class TestCollector:
         assert len(nodes) == 1
         assert isinstance(nodes[0], pytest.File)
 
-class TestCollectFS:
+    def test_can_skip_class_with_test_attr(self, testdir):
+        """Assure test class is skipped when using `__test__=False` (See #2007)."""
+        testdir.makepyfile("""
+            class TestFoo(object):
+                __test__ = False
+                def __init__(self):
+                    pass
+                def test_foo():
+                    assert True
+        """)
+        result = testdir.runpytest()
+        result.stdout.fnmatch_lines([
+            'collected 0 items',
+            '*no tests ran in*',
+        ])
+
+class TestCollectFS(object):
     def test_ignored_certain_directories(self, testdir):
         tmpdir = testdir.tmpdir
         tmpdir.ensure("build", 'test_notfound.py')
@@ -147,11 +164,11 @@ class TestCollectFS:
             assert [x.name for x in items] == ['test_%s' % dirname]
 
 
-class TestCollectPluginHookRelay:
+class TestCollectPluginHookRelay(object):
     def test_pytest_collect_file(self, testdir):
         wascalled = []
 
-        class Plugin:
+        class Plugin(object):
             def pytest_collect_file(self, path, parent):
                 if not path.basename.startswith("."):
                     # Ignore hidden files, e.g. .testmondata.
@@ -165,7 +182,7 @@ class TestCollectPluginHookRelay:
     def test_pytest_collect_directory(self, testdir):
         wascalled = []
 
-        class Plugin:
+        class Plugin(object):
             def pytest_collect_directory(self, path, parent):
                 wascalled.append(path.basename)
 
@@ -176,7 +193,7 @@ class TestCollectPluginHookRelay:
         assert "world" in wascalled
 
 
-class TestPrunetraceback:
+class TestPrunetraceback(object):
 
     def test_custom_repr_failure(self, testdir):
         p = testdir.makepyfile("""
@@ -222,7 +239,7 @@ class TestPrunetraceback:
         ])
 
 
-class TestCustomConftests:
+class TestCustomConftests(object):
     def test_ignore_collect_path(self, testdir):
         testdir.makeconftest("""
             def pytest_ignore_collect(path, config):
@@ -317,7 +334,7 @@ class TestCustomConftests:
             "*test_x*"
         ])
 
-class TestSession:
+class TestSession(object):
     def test_parsearg(self, testdir):
         p = testdir.makepyfile("def test_func(): pass")
         subdir = testdir.mkdir("sub")
@@ -352,6 +369,11 @@ class TestSession:
         assert len(colitems) == 1
         assert colitems[0].fspath == p
 
+    def get_reported_items(self, hookrec):
+        """Return pytest.Item instances reported by the pytest_collectreport hook"""
+        calls = hookrec.getcalls('pytest_collectreport')
+        return [x for call in calls for x in call.report.result
+                if isinstance(x, pytest.Item)]
 
     def test_collect_protocol_single_function(self, testdir):
         p = testdir.makepyfile("def test_func(): pass")
@@ -369,13 +391,14 @@ class TestSession:
             ("pytest_collectstart", "collector.fspath == p"),
             ("pytest_make_collect_report", "collector.fspath == p"),
             ("pytest_pycollect_makeitem", "name == 'test_func'"),
-            ("pytest_collectreport", "report.nodeid.startswith(p.basename)"),
-            ("pytest_collectreport", "report.nodeid == ''")
+            ("pytest_collectreport", "report.result[0].name == 'test_func'"),
         ])
+        # ensure we are reporting the collection of the single test item (#2464)
+        assert [x.name for x in self.get_reported_items(hookrec)] == ['test_func']
 
     def test_collect_protocol_method(self, testdir):
         p = testdir.makepyfile("""
-            class TestClass:
+            class TestClass(object):
                 def test_method(self):
                     pass
         """)
@@ -390,6 +413,8 @@ class TestSession:
             assert items[0].name == "test_method"
             newid = items[0].nodeid
             assert newid == normid
+            # ensure we are reporting the collection of the single test item (#2464)
+            assert [x.name for x in self.get_reported_items(hookrec)] == ['test_method']
 
     def test_collect_custom_nodes_multi_id(self, testdir):
         p = testdir.makepyfile("def test_func(): pass")
@@ -419,9 +444,8 @@ class TestSession:
                 "collector.__class__.__name__ == 'Module'"),
             ("pytest_pycollect_makeitem", "name == 'test_func'"),
             ("pytest_collectreport", "report.nodeid.startswith(p.basename)"),
-            #("pytest_collectreport",
-            #    "report.fspath == %r" % str(rcol.fspath)),
         ])
+        assert len(self.get_reported_items(hookrec)) == 2
 
     def test_collect_subdir_event_ordering(self, testdir):
         p = testdir.makepyfile("def test_func(): pass")
@@ -474,17 +498,19 @@ class TestSession:
 
     def test_find_byid_without_instance_parents(self, testdir):
         p = testdir.makepyfile("""
-            class TestClass:
+            class TestClass(object):
                 def test_method(self):
                     pass
         """)
-        arg = p.basename + ("::TestClass::test_method")
+        arg = p.basename + "::TestClass::test_method"
         items, hookrec = testdir.inline_genitems(arg)
         assert len(items) == 1
         item, = items
         assert item.nodeid.endswith("TestClass::()::test_method")
+        # ensure we are reporting the collection of the single test item (#2464)
+        assert [x.name for x in self.get_reported_items(hookrec)] == ['test_method']
 
-class Test_getinitialnodes:
+class Test_getinitialnodes(object):
     def test_global_file(self, testdir, tmpdir):
         x = tmpdir.ensure("x.py")
         with tmpdir.as_cwd():
@@ -511,7 +537,7 @@ class Test_getinitialnodes:
         for col in col.listchain():
             assert col.config is config
 
-class Test_genitems:
+class Test_genitems(object):
     def test_check_collect_hashes(self, testdir):
         p = testdir.makepyfile("""
             def test_1():
@@ -534,7 +560,7 @@ class Test_genitems:
             def testone():
                 pass
 
-            class TestX:
+            class TestX(object):
                 def testmethod_one(self):
                     pass
 
@@ -567,11 +593,11 @@ class Test_genitems:
             python_functions = *_test test
         """)
         p = testdir.makepyfile('''
-            class MyTestSuite:
+            class MyTestSuite(object):
                 def x_test(self):
                     pass
 
-            class TestCase:
+            class TestCase(object):
                 def test_y(self):
                     pass
         ''')
@@ -586,7 +612,7 @@ def test_matchnodes_two_collections_same_file(testdir):
         def pytest_configure(config):
             config.pluginmanager.register(Plugin2())
 
-        class Plugin2:
+        class Plugin2(object):
             def pytest_collect_file(self, path, parent):
                 if path.ext == ".abc":
                     return MyFile2(path, parent)
@@ -618,7 +644,7 @@ def test_matchnodes_two_collections_same_file(testdir):
     ])
 
 
-class TestNodekeywords:
+class TestNodekeywords(object):
     def test_no_under(self, testdir):
         modcol = testdir.getmodulecol("""
             def test_pass(): pass
