@@ -1,10 +1,11 @@
+from __future__ import absolute_import, division, print_function
 import py, pytest
 
 import _pytest._code
 from _pytest.config import getcfg, get_common_ancestor, determine_setup
 from _pytest.main import EXIT_NOTESTSCOLLECTED
 
-class TestParseIni:
+class TestParseIni(object):
 
     @pytest.mark.parametrize('section, filename',
                              [('pytest', 'pytest.ini'), ('tool:pytest', 'setup.cfg')])
@@ -84,7 +85,7 @@ class TestParseIni:
         result = testdir.inline_run("--confcutdir=.")
         assert result.ret == 0
 
-class TestConfigCmdlineParsing:
+class TestConfigCmdlineParsing(object):
     def test_parsing_again_fails(self, testdir):
         config = testdir.parseconfig()
         pytest.raises(AssertionError, lambda: config.parse([]))
@@ -115,7 +116,7 @@ class TestConfigCmdlineParsing:
         ret = pytest.main("-c " + temp_cfg_file)
         assert ret == _pytest.main.EXIT_OK
 
-class TestConfigAPI:
+class TestConfigAPI(object):
     def test_config_trace(self, testdir):
         config = testdir.parseconfig()
         l = []
@@ -140,7 +141,7 @@ class TestConfigAPI:
             from __future__ import unicode_literals
 
             def pytest_addoption(parser):
-                parser.addoption('--hello', type='string')
+                parser.addoption('--hello', type=str)
         """)
         config = testdir.parseconfig('--hello=this')
         assert config.getoption('hello') == 'this'
@@ -304,7 +305,7 @@ class TestConfigAPI:
         assert config.getoption('confcutdir') == str(testdir.tmpdir.join('dir'))
 
 
-class TestConfigFromdictargs:
+class TestConfigFromdictargs(object):
     def test_basic_behavior(self):
         from _pytest.config import Config
         option_dict = {
@@ -389,19 +390,19 @@ def test_preparse_ordering_with_setuptools(testdir, monkeypatch):
     def my_iter(name):
         assert name == "pytest11"
 
-        class Dist:
+        class Dist(object):
             project_name = 'spam'
             version = '1.0'
 
             def _get_metadata(self, name):
                 return ['foo.txt,sha256=abc,123']
 
-        class EntryPoint:
+        class EntryPoint(object):
             name = "mytestplugin"
             dist = Dist()
 
             def load(self):
-                class PseudoPlugin:
+                class PseudoPlugin(object):
                     x = 42
                 return PseudoPlugin()
 
@@ -423,14 +424,14 @@ def test_setuptools_importerror_issue1479(testdir, monkeypatch):
     def my_iter(name):
         assert name == "pytest11"
 
-        class Dist:
+        class Dist(object):
             project_name = 'spam'
             version = '1.0'
 
             def _get_metadata(self, name):
                 return ['foo.txt,sha256=abc,123']
 
-        class EntryPoint:
+        class EntryPoint(object):
             name = "mytestplugin"
             dist = Dist()
 
@@ -450,14 +451,14 @@ def test_plugin_preparse_prevents_setuptools_loading(testdir, monkeypatch):
     def my_iter(name):
         assert name == "pytest11"
 
-        class Dist:
+        class Dist(object):
             project_name = 'spam'
             version = '1.0'
 
             def _get_metadata(self, name):
                 return ['foo.txt,sha256=abc,123']
 
-        class EntryPoint:
+        class EntryPoint(object):
             name = "mytestplugin"
             dist = Dist()
 
@@ -519,7 +520,7 @@ def test_consider_args_after_options_for_rootdir_and_inifile(testdir, args):
             args[i] = d2
     with root.as_cwd():
         result = testdir.runpytest(*args)
-    result.stdout.fnmatch_lines(['*rootdir: *myroot, inifile: '])
+    result.stdout.fnmatch_lines(['*rootdir: *myroot, inifile:'])
 
 
 @pytest.mark.skipif("sys.platform == 'win32'")
@@ -557,7 +558,7 @@ def test_notify_exception(testdir, capfd):
     out, err = capfd.readouterr()
     assert "ValueError" in err
 
-    class A:
+    class A(object):
         def pytest_internalerror(self, excrepr):
             return True
 
@@ -571,7 +572,7 @@ def test_load_initial_conftest_last_ordering(testdir):
     from _pytest.config  import get_config
     pm = get_config().pluginmanager
 
-    class My:
+    class My(object):
         def pytest_load_initial_conftests(self):
             pass
 
@@ -602,7 +603,7 @@ def test_get_plugin_specs_as_list():
     assert _get_plugin_specs_as_list(('foo', 'bar')) == ['foo', 'bar']
 
 
-class TestWarning:
+class TestWarning(object):
     def test_warn_config(self, testdir):
         testdir.makeconftest("""
             l = []
@@ -632,16 +633,17 @@ class TestWarning:
                 pass
         """)
         result = testdir.runpytest("--disable-pytest-warnings")
-        assert result.parseoutcomes()["pytest-warnings"] > 0
+        assert result.parseoutcomes()["warnings"] > 0
         assert "hello" not in result.stdout.str()
 
         result = testdir.runpytest()
         result.stdout.fnmatch_lines("""
-            ===*pytest-warning summary*===
-            *WT1*test_warn_on_test_item*:7 hello*
+            ===*warnings summary*===
+            *test_warn_on_test_item_from_request.py::test_hello*
+            *hello*
         """)
 
-class TestRootdir:
+class TestRootdir(object):
     def test_simple_noini(self, tmpdir):
         assert get_common_ancestor([tmpdir]) == tmpdir
         a = tmpdir.mkdir("a")
@@ -699,7 +701,7 @@ class TestRootdir:
         assert rootdir == tmpdir
 
 
-class TestOverrideIniArgs:
+class TestOverrideIniArgs(object):
     @pytest.mark.parametrize("name", "setup.cfg tox.ini pytest.ini".split())
     def test_override_ini_names(self, testdir, name):
         testdir.tmpdir.join(name).write(py.std.textwrap.dedent("""
@@ -778,6 +780,21 @@ class TestOverrideIniArgs:
         result = testdir.runpytest("--override-ini", 'xdist_strict True', "-s")
         result.stderr.fnmatch_lines(["*ERROR* *expects option=value*"])
 
+    @pytest.mark.parametrize('with_ini', [True, False])
+    def test_override_ini_handled_asap(self, testdir, with_ini):
+        """-o should be handled as soon as possible and always override what's in ini files (#2238)"""
+        if with_ini:
+            testdir.makeini("""
+                [pytest]
+                python_files=test_*.py
+            """)
+        testdir.makepyfile(unittest_ini_handle="""
+            def test():
+                pass
+        """)
+        result = testdir.runpytest("--override-ini", 'python_files=unittest_*.py')
+        result.stdout.fnmatch_lines(["*1 passed in*"])
+
     def test_with_arg_outside_cwd_without_inifile(self, tmpdir, monkeypatch):
         monkeypatch.chdir(str(tmpdir))
         a = tmpdir.mkdir("a")
