@@ -1,4 +1,5 @@
 # encoding: utf-8
+from __future__ import absolute_import, division, print_function
 import sys
 import _pytest._code
 from _pytest.compat import MODULE_NOT_FOUND_ERROR
@@ -6,7 +7,7 @@ from _pytest.doctest import DoctestItem, DoctestModule, DoctestTextfile
 import pytest
 
 
-class TestDoctests:
+class TestDoctests(object):
 
     def test_collect_testtextfile(self, testdir):
         w = testdir.maketxtfile(whatever="")
@@ -131,6 +132,33 @@ class TestDoctests:
             '*1 passed*',
         ])
 
+    @pytest.mark.parametrize(
+        '   test_string,    encoding',
+        [
+            (u'foo',         'ascii'),
+            (u'öäü',         'latin1'),
+            (u'öäü',         'utf-8')
+        ]
+    )
+    def test_encoding(self, testdir, test_string, encoding):
+        """Test support for doctest_encoding ini option.
+        """
+        testdir.makeini("""
+            [pytest]
+            doctest_encoding={0}
+        """.format(encoding))
+        doctest = u"""
+            >>> u"{0}"
+            {1}
+        """.format(test_string, repr(test_string))
+        testdir._makefile(".txt", [doctest], {}, encoding=encoding)
+
+        result = testdir.runpytest()
+
+        result.stdout.fnmatch_lines([
+            '*1 passed*',
+        ])
+
     def test_doctest_unexpected_exception(self, testdir):
         testdir.maketxtfile("""
             >>> i = 0
@@ -351,7 +379,7 @@ class TestDoctests:
 
     def test_doctestmodule_two_tests_one_fail(self, testdir):
         p = testdir.makepyfile("""
-            class MyClass:
+            class MyClass(object):
                 def bad_meth(self):
                     '''
                     >>> magic = 42
@@ -374,7 +402,7 @@ class TestDoctests:
             doctest_optionflags = ELLIPSIS NORMALIZE_WHITESPACE
         """)
         p = testdir.makepyfile("""
-            class MyClass:
+            class MyClass(object):
                 '''
                 >>> a = "foo    "
                 >>> print(a)
@@ -391,7 +419,7 @@ class TestDoctests:
             doctest_optionflags = ELLIPSIS
         """)
         p = testdir.makepyfile("""
-            class MyClass:
+            class MyClass(object):
                 '''
                 >>> a = "foo    "
                 >>> print(a)
@@ -477,8 +505,49 @@ class TestDoctests:
                                     "--junit-xml=junit.xml")
         reprec.assertoutcome(failed=1)
 
+    def test_unicode_doctest(self, testdir):
+        """
+        Test case for issue 2434: DecodeError on Python 2 when doctest contains non-ascii
+        characters.
+        """
+        p = testdir.maketxtfile(test_unicode_doctest="""
+            .. doctest::
 
-class TestLiterals:
+                >>> print(
+                ...    "Hi\\n\\nByé")
+                Hi
+                ...
+                Byé
+                >>> 1/0  # Byé
+                1
+        """)
+        result = testdir.runpytest(p)
+        result.stdout.fnmatch_lines([
+            '*UNEXPECTED EXCEPTION: ZeroDivisionError*',
+            '*1 failed*',
+        ])
+
+    def test_unicode_doctest_module(self, testdir):
+        """
+        Test case for issue 2434: DecodeError on Python 2 when doctest docstring
+        contains non-ascii characters.
+        """
+        p = testdir.makepyfile(test_unicode_doctest_module="""
+            # -*- encoding: utf-8 -*-
+            from __future__ import unicode_literals
+            
+            def fix_bad_unicode(text):
+                '''
+                    >>> print(fix_bad_unicode('Ãºnico'))
+                    único
+                '''
+                return "único"
+        """)
+        result = testdir.runpytest(p, '--doctest-modules')
+        result.stdout.fnmatch_lines(['* 1 passed *'])
+
+
+class TestLiterals(object):
 
     @pytest.mark.parametrize('config_mode', ['ini', 'comment'])
     def test_allow_unicode(self, testdir, config_mode):
@@ -565,7 +634,7 @@ class TestLiterals:
         reprec.assertoutcome(passed=passed, failed=int(not passed))
 
 
-class TestDoctestSkips:
+class TestDoctestSkips(object):
     """
     If all examples in a doctest are skipped due to the SKIP option, then
     the tests should be SKIPPED rather than PASSED. (#957)
@@ -619,7 +688,7 @@ class TestDoctestSkips:
         reprec.assertoutcome(passed=0, skipped=0)
 
 
-class TestDoctestAutoUseFixtures:
+class TestDoctestAutoUseFixtures(object):
 
     SCOPES = ['module', 'session', 'class', 'function']
 
@@ -738,7 +807,7 @@ class TestDoctestAutoUseFixtures:
         result.stdout.fnmatch_lines(['*=== 1 passed in *'])
 
 
-class TestDoctestNamespaceFixture:
+class TestDoctestNamespaceFixture(object):
 
     SCOPES = ['module', 'session', 'class', 'function']
 
@@ -788,7 +857,7 @@ class TestDoctestNamespaceFixture:
         reprec.assertoutcome(passed=1)
 
 
-class TestDoctestReportingOption:
+class TestDoctestReportingOption(object):
     def _run_doctest_report(self, testdir, format):
         testdir.makepyfile("""
             def foo():
