@@ -1,6 +1,7 @@
 """
 terminal reporting of the full testing process.
 """
+from __future__ import absolute_import, division, print_function
 import collections
 import sys
 
@@ -16,7 +17,7 @@ from _pytest.terminal import build_summary_stats_line, _plugin_nameversions
 DistInfo = collections.namedtuple('DistInfo', ['project_name', 'version'])
 
 
-class Option:
+class Option(object):
     def __init__(self, verbose=False, fulltrace=False):
         self.verbose = verbose
         self.fulltrace = fulltrace
@@ -56,7 +57,7 @@ def test_plugin_nameversion(input, expected):
     assert result == expected
 
 
-class TestTerminal:
+class TestTerminal(object):
     def test_pass_skip_fail(self, testdir, option):
         testdir.makepyfile("""
             import pytest
@@ -127,7 +128,7 @@ class TestTerminal:
 
     def test_itemreport_subclasses_show_subclassed_file(self, testdir):
         testdir.makepyfile(test_p1="""
-            class BaseTests:
+            class BaseTests(object):
                 def test_p1(self):
                     pass
             class TestClass(BaseTests):
@@ -151,7 +152,7 @@ class TestTerminal:
     def test_itemreport_directclasses_not_shown_as_subclasses(self, testdir):
         a = testdir.mkpydir("a123")
         a.join("test_hello123.py").write(_pytest._code.Source("""
-            class TestClass:
+            class TestClass(object):
                 def test_method(self):
                     pass
         """))
@@ -203,8 +204,17 @@ class TestTerminal:
         assert result.ret == 2
         result.stdout.fnmatch_lines(['*KeyboardInterrupt*'])
 
+    def test_collect_single_item(self, testdir):
+        """Use singular 'item' when reporting a single test item"""
+        testdir.makepyfile("""
+            def test_foobar():
+                pass
+        """)
+        result = testdir.runpytest()
+        result.stdout.fnmatch_lines(['collected 1 item'])
 
-class TestCollectonly:
+
+class TestCollectonly(object):
     def test_collectonly_basic(self, testdir):
         testdir.makepyfile("""
             def test_func():
@@ -249,7 +259,7 @@ class TestCollectonly:
         p = testdir.makepyfile("""
             def test_func1():
                 pass
-            class TestClass:
+            class TestClass(object):
                 def test_method(self):
                     pass
         """)
@@ -310,7 +320,7 @@ def test_repr_python_version(monkeypatch):
     finally:
         monkeypatch.undo() # do this early as pytest can get confused
 
-class TestFixtureReporting:
+class TestFixtureReporting(object):
     def test_setup_fixture_error(self, testdir):
         testdir.makepyfile("""
             def setup_function(function):
@@ -395,7 +405,7 @@ class TestFixtureReporting:
             "*1 failed*",
          ])
 
-class TestTerminalFunctional:
+class TestTerminalFunctional(object):
     def test_deselected(self, testdir):
         testpath = testdir.makepyfile("""
                 def test_one():
@@ -431,7 +441,7 @@ class TestTerminalFunctional:
         p1 = testdir.makepyfile("""
             def test_passes():
                 pass
-            class TestClass:
+            class TestClass(object):
                 def test_method(self):
                     pass
         """)
@@ -487,7 +497,7 @@ class TestTerminalFunctional:
                 raise ValueError()
             def test_pass():
                 pass
-            class TestClass:
+            class TestClass(object):
                 def test_skip(self):
                     pytest.skip("hello")
             def test_gen():
@@ -612,10 +622,10 @@ def test_color_yes_collection_on_non_atty(testdir, verbose):
 
 
 def test_getreportopt():
-    class config:
-        class option:
+    class config(object):
+        class option(object):
             reportchars = ""
-            disablepytestwarnings = True
+            disable_warnings = True
 
     config.option.reportchars = "sf"
     assert getreportopt(config) == "sf"
@@ -624,11 +634,11 @@ def test_getreportopt():
     assert getreportopt(config) == "sfx"
 
     config.option.reportchars = "sfx"
-    config.option.disablepytestwarnings = False
+    config.option.disable_warnings = False
     assert getreportopt(config) == "sfxw"
 
     config.option.reportchars = "sfxw"
-    config.option.disablepytestwarnings = False
+    config.option.disable_warnings = False
     assert getreportopt(config) == "sfxw"
 
 
@@ -683,7 +693,7 @@ def test_traceconfig(testdir, monkeypatch):
     assert result.ret == EXIT_NOTESTSCOLLECTED
 
 
-class TestGenericReporting:
+class TestGenericReporting(object):
     """ this test class can be subclassed with a different option
         provider to run e.g. distributed tests.
     """
@@ -837,8 +847,8 @@ def test_terminal_summary_warnings_are_displayed(testdir):
     """)
     result = testdir.runpytest('-rw')
     result.stdout.fnmatch_lines([
-        '*C1*internal warning',
-        '*== 1 pytest-warnings in *',
+        '*internal warning',
+        '*== 1 warnings in *',
     ])
 
 
@@ -858,9 +868,9 @@ def test_terminal_summary_warnings_are_displayed(testdir):
     ("yellow", "1 weird", {"weird": (1,)}),
     ("yellow", "1 passed, 1 weird", {"weird": (1,), "passed": (1,)}),
 
-    ("yellow", "1 pytest-warnings", {"warnings": (1,)}),
-    ("yellow", "1 passed, 1 pytest-warnings", {"warnings": (1,),
-                                               "passed": (1,)}),
+    ("yellow", "1 warnings", {"warnings": (1,)}),
+    ("yellow", "1 passed, 1 warnings", {"warnings": (1,),
+                                        "passed": (1,)}),
 
     ("green", "5 passed", {"passed": (1,2,3,4,5)}),
 
@@ -906,3 +916,12 @@ def test_summary_stats(exp_line, exp_color, stats_arg):
     print("Actually got:   \"%s\"; with color \"%s\"" % (line, color))
     assert line == exp_line
     assert color == exp_color
+
+
+def test_no_trailing_whitespace_after_inifile_word(testdir):
+    result = testdir.runpytest('')
+    assert 'inifile:\n' in result.stdout.str()
+
+    testdir.makeini('[pytest]')
+    result = testdir.runpytest('')
+    assert 'inifile: tox.ini\n' in result.stdout.str()
